'use strict';

var base = require('base/checkout/billing');
var cleave = require('base/components/cleave');
var redsysHelper = require('./redsysHelper');

/**
 * @function changePaymentMethod
 * @description Change payment method option
 */
base.updatePaymentMethodId = function () {
    $('.payment-options .nav-link').click(function setAttr() {
        $('#selectedPaymentOption').val($(this).parent().attr('data-method-id'));
    });
};

/**
 * @function handleCreditCardNumber
 * @description Handle credit card number
 */
base.handleCreditCardNumber = function () {
    if ($('.cardNumber').length > 0 && $('#cardType').length > 0) {
        cleave.handleCreditCardNumber('.cardNumber', '#cardType');
    }
};

/**
 * @function changePaymentMethod
 * @description Change payment method option
 */
base.changePaymentMethod = function () {
    $('.payment-options a[data-toggle="tab"]').on('click', function () {
        var activePaymentMethod = $(this).attr('href');
        var activePaymentMethodName = $(this).parent().attr('data-method-id');
        var paymentMethods = $('.payment-options a[data-toggle="tab"]');

        if (activePaymentMethod && activePaymentMethodName) {
            redsysHelper.setPaymentMethodId(activePaymentMethodName);
        }

        paymentMethods.each(function (i, paymentMethod) {
            var payment = $(paymentMethod).attr('href');
            $(payment).find('input, select, button').prop('disabled', payment !== activePaymentMethod);
        });
    });
};

/**
 * @function setDefaultPaymentMethod
 * @description Set active one payment method if not exist
 */
base.setDefaultPaymentMethod = function () {
    var activePaymentMethodId = redsysHelper.getPaymentMethodId();

    if (!activePaymentMethodId) {
        var paymentMethods = $('.payment-options a[data-toggle="tab"]');
        paymentMethods.each(function (i, paymentMethod) {
            $(paymentMethod).trigger('click');
            return false;
        });
    }
};

/**
 * Validate and update payment instrument form fields
 * @param {Object} order - the order model
 */
base.methods.validateAndUpdateBillingPaymentInstrument = function (order) {
    var activePaymentMethodId = redsysHelper.getPaymentMethodId();

    if (!order || activePaymentMethodId === 'REDSYS_CREDIT_CARD' ||
        activePaymentMethodId === 'REDSYS_BIZUM') {
        return;
    // eslint-disable-next-line no-else-return
    } else {
        var billing = order.billing;
        if (!billing.payment || !billing.payment.selectedPaymentInstruments
            || billing.payment.selectedPaymentInstruments.length <= 0) return;

        var form = $('form[name=dwfrm_billing]');
        if (!form) return;

        var instrument = billing.payment.selectedPaymentInstruments[0];
        $('select[name$=expirationMonth]', form).val(instrument.expirationMonth);
        $('select[name$=expirationYear]', form).val(instrument.expirationYear);
        // Force security code and card number clear
        $('input[name$=securityCode]', form).val('');
        $('input[name$=cardNumber]').data('cleave').setRawValue('');
    }
};

/**
 * Updates the payment information in checkout, based on the supplied order model
 * @param {Object} order - checkout model to use as basis of new truth
 */
base.methods.updatePaymentInformation = function (order) {
    // update payment details
    var $paymentSummary = $('.payment-details');
    var htmlToAppend = '';

    if (order.billing.payment && order.billing.payment.selectedPaymentInstruments
        && order.billing.payment.selectedPaymentInstruments.length > 0) {
        if (order.billing.payment.selectedPaymentInstruments[0].paymentMethod === 'CREDIT_CARD') {
            htmlToAppend += '<span>' + order.resources.cardType + ' '
                + order.billing.payment.selectedPaymentInstruments[0].type
                + '</span><div>'
                + order.billing.payment.selectedPaymentInstruments[0].maskedCreditCardNumber
                + '</div><div><span>'
                + order.resources.cardEnding + ' '
                + order.billing.payment.selectedPaymentInstruments[0].expirationMonth
                + '/' + order.billing.payment.selectedPaymentInstruments[0].expirationYear
                + '</span></div>';
        } else if (order.billing.payment.selectedPaymentInstruments[0].paymentMethod === 'REDSYS_BIZUM' ||
        order.billing.payment.selectedPaymentInstruments[0].paymentMethod === 'REDSYS_CREDIT_CARD') {
            htmlToAppend += '<span>'
            + order.resources.cardType
            + '</span><br/>';
        }
        $paymentSummary.empty().append(htmlToAppend);
    }
};

module.exports = base;
